Service prices are optional (the default is zero price for all requests).

If specified, the following fields are required:
 - `base_price`: the base price of a request (dollars)
 - `price_per_mile`: an additional price per mile (dollars)
 - `minimum_price`: the minimum request price (dollars)